@@ -2,7 +2,6 @@
 import gettext
 import locale
 import os
-import platform
 import subprocess
 import sys
 
@@ -24,10 +23,6 @@ _ = gettext.gettext
 class PPA_Browser():
 
     def __init__(self, base_codename, ppa_file, ppa_owner, ppa_name):
-        if platform.machine() == "x86_64":
-            architecture = "amd64"
-        else:
-            architecture = "i386"
         ppa_origin = "LP-PPA-%s-%s" % (ppa_owner, ppa_name)
         ppa_origin_simple = "LP-PPA-%s" % (ppa_owner)
 
@@ -110,7 +105,7 @@ class PPA_Browser():
 
     def toggled (self, renderer, path):
         iter = self.model.get_iter(path)
-        if (iter != None):
+        if iter is not None:
             pkg = self.model.get_value(iter, 0)
             if pkg.name in self.packages_to_install:
                 self.packages_to_install.remove(pkg.name)
